IF NOT EXISTS (SELECT 1 FROM sys.schemas WHERE name = 'extension')
BEGIN
    EXEC('CREATE SCHEMA [extension] AUTHORIZATION dbo')
END
GO

-- ********************************************************************************
--    InstitutionControlType
-- ********************************************************************************
CREATE TABLE extension.InstitutionControlType(
	InstitutionControlTypeId int IDENTITY(1,1) NOT NULL,
	CodeValue nvarchar(50) NOT NULL,
	[Description] nvarchar(1024) NOT NULL,
	ShortDescription nvarchar(450) NOT NULL,
	Id uniqueidentifier NOT NULL,
	LastModifiedDate datetime NOT NULL,
	CreateDate datetime NOT NULL,
	CONSTRAINT PK_InstitutionControlType PRIMARY KEY CLUSTERED (InstitutionControlTypeId ASC)
)  

ALTER TABLE extension.InstitutionControlType ADD CONSTRAINT [InstitutionControlType_DF_Id]  DEFAULT (newid()) FOR [Id]
ALTER TABLE extension.InstitutionControlType ADD CONSTRAINT [InstitutionControlType_DF_LastModifiedDate]  DEFAULT (getdate()) FOR [LastModifiedDate]
ALTER TABLE extension.InstitutionControlType ADD CONSTRAINT [InstitutionControlType_CreateDate]  DEFAULT (getdate()) FOR [CreateDate]

GO

-- ********************************************************************************
--    InstitutionLevelType
-- ********************************************************************************
CREATE TABLE extension.InstitutionLevelType(
	InstitutionLevelTypeId int IDENTITY(1,1) NOT NULL,
	CodeValue nvarchar(50) NOT NULL,
	[Description] nvarchar(1024) NOT NULL,
	ShortDescription nvarchar(450) NOT NULL,
	Id uniqueidentifier NOT NULL,
	LastModifiedDate datetime NOT NULL,
	CreateDate datetime NOT NULL,
	CONSTRAINT PK_InstitutionLevelType PRIMARY KEY CLUSTERED (InstitutionLevelTypeId ASC)
)  

ALTER TABLE extension.InstitutionLevelType ADD CONSTRAINT [InstitutionLevelType_DF_Id]  DEFAULT (newid()) FOR [Id]
ALTER TABLE extension.InstitutionLevelType ADD CONSTRAINT [InstitutionLevelType_DF_LastModifiedDate]  DEFAULT (getdate()) FOR [LastModifiedDate]
ALTER TABLE extension.InstitutionLevelType ADD CONSTRAINT [InstitutionLevelType_CreateDate]  DEFAULT (getdate()) FOR [CreateDate]

GO

-- ********************************************************************************
--    SpecialEducationGraduationStatusType
-- ********************************************************************************

CREATE TABLE extension.SpecialEducationGraduationStatusType(
	SpecialEducationGraduationStatusTypeId int IDENTITY(1,1) NOT NULL,
	CodeValue nvarchar(50) NOT NULL,
	[Description] nvarchar(1024) NOT NULL,
	ShortDescription nvarchar(450) NOT NULL,
	Id uniqueidentifier NOT NULL,
	LastModifiedDate datetime NOT NULL,
	CreateDate datetime NOT NULL,
	CONSTRAINT PK_SpecialEducationGraduationStatusType PRIMARY KEY CLUSTERED (SpecialEducationGraduationStatusTypeId ASC)
)  

ALTER TABLE extension.SpecialEducationGraduationStatusType ADD CONSTRAINT [SpecialEducationGraduationStatusType_DF_Id]  DEFAULT (newid()) FOR [Id]
ALTER TABLE extension.SpecialEducationGraduationStatusType ADD CONSTRAINT [SpecialEducationGraduationStatusType_DF_LastModifiedDate]  DEFAULT (getdate()) FOR [LastModifiedDate]
ALTER TABLE extension.SpecialEducationGraduationStatusType ADD CONSTRAINT [SpecialEducationGraduationStatusType_CreateDate]  DEFAULT (getdate()) FOR [CreateDate]

GO

-- ********************************************************************************
--    SubmissionCertificationType
-- ********************************************************************************

CREATE TABLE extension.SubmissionCertificationType(
	SubmissionCertificationTypeId int IDENTITY(1,1) NOT NULL,
	CodeValue nvarchar(50) NOT NULL,
	[Description] nvarchar(1024) NOT NULL,
	ShortDescription nvarchar(450) NOT NULL,
	Id uniqueidentifier NOT NULL,
	LastModifiedDate datetime NOT NULL,
	CreateDate datetime NOT NULL,
	CONSTRAINT PK_SubmissionCertificationType PRIMARY KEY CLUSTERED (SubmissionCertificationTypeId ASC)
)  

ALTER TABLE extension.SubmissionCertificationType ADD CONSTRAINT [SubmissionCertificationType_DF_Id]  DEFAULT (newid()) FOR [Id]
ALTER TABLE extension.SubmissionCertificationType ADD CONSTRAINT [SubmissionCertificationType_DF_LastModifiedDate]  DEFAULT (getdate()) FOR [LastModifiedDate]
ALTER TABLE extension.SubmissionCertificationType ADD CONSTRAINT [SubmissionCertificationType_CreateDate]  DEFAULT (getdate()) FOR [CreateDate]

GO

-- ********************************************************************************
--    PostSecondaryOrganization
-- ********************************************************************************

CREATE TABLE extension.PostSecondaryOrganization(
    [NameOfInstitution]           nvarchar(75)     NOT NULL,
	[InstitutionLevelTypeId]      int              NOT NULL,
	[InstitutionControlTypeId]    int              NOT NULL,
    [AcceptanceIndicator]      bit              NOT NULL,
	[Id]                          uniqueidentifier NOT NULL,
	[LastModifiedDate]            datetime         NOT NULL,
	[CreateDate]                  datetime         NOT NULL,
	CONSTRAINT PK_PostSecondaryOrganization PRIMARY KEY CLUSTERED (NameOfInstitution ASC)
)  

ALTER TABLE extension.PostSecondaryOrganization ADD CONSTRAINT [PostSecondaryOrganization_DF_Id]  DEFAULT (newid()) FOR [Id]
ALTER TABLE extension.PostSecondaryOrganization ADD CONSTRAINT [PostSecondaryOrganization_DF_LastModifiedDate]  DEFAULT (getdate()) FOR [LastModifiedDate]
ALTER TABLE extension.PostSecondaryOrganization ADD CONSTRAINT [PostSecondaryOrganization_CreateDate]  DEFAULT (getdate()) FOR [CreateDate]

GO

ALTER TABLE [extension].[PostSecondaryOrganization] ADD CONSTRAINT [FK_PostSecondaryOrganization_InstitutionLevelTypeId] FOREIGN KEY([InstitutionLevelTypeId])
REFERENCES [extension].[InstitutionLevelType] ([InstitutionLevelTypeId])
GO

ALTER TABLE [extension].[PostSecondaryOrganization] ADD CONSTRAINT [FK_PostSecondaryOrganization_InstitutionControlTypeId] FOREIGN KEY([InstitutionControlTypeId])
REFERENCES [extension].[InstitutionControlType] ([InstitutionControlTypeId])
GO


-- ********************************************************************************
--    StudentAcademicRecordExtension
-- ********************************************************************************

CREATE TABLE [extension].[StudentAcademicRecordExtension](
    [StudentUSI]                           int                 NOT NULL,
    [EducationOrganizationId]              int                 NOT NULL,
    [SchoolYear]                           smallint            NOT NULL,
    [TermDescriptorId]                     int                 NOT NULL,
    [NameOfInstitution]                    nvarchar(75)        NOT NULL,
    [SubmissionCertificationTypeId]        int                 NOT NULL,
    CONSTRAINT [PK_StudentAcademicRecordExtension] PRIMARY KEY CLUSTERED ([StudentUSI], [EducationOrganizationId], [SchoolYear], [TermDescriptorId])
)

GO

ALTER TABLE [extension].[StudentAcademicRecordExtension] ADD CONSTRAINT [FK_StudentAcademicRecordExtension_NameOfInstitution] FOREIGN KEY([NameOfInstitution])
REFERENCES [extension].[PostSecondaryOrganization] ([NameOfInstitution])
GO

ALTER TABLE [extension].[StudentAcademicRecordExtension] ADD CONSTRAINT [FK_StudentAcademicRecordExtension_SubmissionCertificationTypeId] FOREIGN KEY([SubmissionCertificationTypeId])
REFERENCES [extension].[SubmissionCertificationType] ([SubmissionCertificationTypeId])
GO

ALTER TABLE [extension].[StudentAcademicRecordExtension] ADD CONSTRAINT [FK_StudentAcademicRecordExtension_StudentAcademicRecord] 
    FOREIGN KEY ([StudentUSI], [EducationOrganizationId], [SchoolYear], [TermDescriptorId])
    REFERENCES [edfi].[StudentAcademicRecord]([StudentUSI], [EducationOrganizationId], [SchoolYear], [TermDescriptorId])
go


-- ********************************************************************************
--    StudentAcademicRecordClassRankingExtension
-- ********************************************************************************

CREATE TABLE [extension].[StudentAcademicRecordClassRankingExtension](
    [StudentUSI]                              int         NOT NULL,
    [SchoolYear]                              smallint    NOT NULL,
    [TermDescriptorId]                        int         NOT NULL,
    [EducationOrganizationId]                 int         NOT NULL,
	[SpecialEducationGraduationStatusTypeId]  int         NOT NULL,
    [CreateDate]               datetime    CONSTRAINT [StudentAcademicRecordClassRanking_DF_CreateDate] DEFAULT (getdate()) NOT NULL,
    CONSTRAINT [PK_StudentAcademicRecordClassRankingExtension] PRIMARY KEY CLUSTERED ([StudentUSI], [SchoolYear], [TermDescriptorId], [EducationOrganizationId])
)

GO

ALTER TABLE [extension].[StudentAcademicRecordClassRankingExtension] ADD CONSTRAINT [FK_StudentAcademicRecordClassRankingExtension_StudentAcademicRecordExtension] 
    FOREIGN KEY ([StudentUSI], [EducationOrganizationId], [SchoolYear], [TermDescriptorId])
    REFERENCES [extension].[StudentAcademicRecordExtension]([StudentUSI], [EducationOrganizationId], [SchoolYear], [TermDescriptorId])
go

ALTER TABLE [extension].[StudentAcademicRecordClassRankingExtension] ADD CONSTRAINT [FK_StudentAcademicRecordClassRankingExtension_SpecialEducationGraduationStatusTypeId] FOREIGN KEY([SpecialEducationGraduationStatusTypeId])
REFERENCES [extension].[SpecialEducationGraduationStatusType] ([SpecialEducationGraduationStatusTypeId])
GO
